@@ -20,5 +20,5 @@
   rows <- eval(rowFilter, mldrObject$dataset, parent.frame())
   newDataset <- mldrObject$dataset[rows, 1:mldrObject$measures$num.attributes]
 
-  mldr_from_dataframe(newDataset, labelIndices = mldrObject$labels$index, name = mldrObject$name)
+  mldr_from_dataframe(newDataset, labelIndices = mldrObject$labels$index, name = mldrObject$name, attributes = mldrObject$attributes)
 }
